@@ -162,7 +162,7 @@ def call_out_ajax(request: HttpRequest):
 
     captcha_is_valid, captcha_failures = verify_captcha(captcha_token)
     if not captcha_is_valid:
-        message = f"Invalid captcha token : " + ", ".join(captcha_failures)
+        message = "Invalid captcha token : " + ", ".join(captcha_failures)
         capture_message(message)
         return HttpResponseBadRequest(message)
 
@@ -204,6 +204,7 @@ def call_out_ajax(request: HttpRequest):
     if any(
         number not in DISTRICT_TO_MP
         for number in call_out_email.circonscription_numbers.split(',')
+        if len(number) > 0
     ):
         message = (
             "Circonscription number not found: '"
