@@ -1,7 +1,7 @@
 import time
 from argparse import ArgumentParser
 
-from django.core.management import BaseCommand
+from . import BaseCommand
 
 from appel_crises.models import Signature
 
