@@ -2,7 +2,6 @@ import time
 from typing import List
 
 from . import BaseCommand
-from sentry_sdk import capture_message
 
 from appel_crises.mailer import get_delivered_emails, DeliveryResult
 from appel_crises.models import EmailOffset, Signature
@@ -34,7 +33,8 @@ class Command(BaseCommand):
                     counter += 1
                 else:
                     self.stderr.write(f"Email not in the database: {email}")
-                    capture_message(f"Email not in the database: {email}")
+                    # Too much events for sentry ...
+                    # capture_message(f"Email not in the database: {email}")
 
         EmailOffset(offset=offset).save()
         stop = time.time()
