@@ -1,5 +1,6 @@
 from datetime import datetime
 
+from django.conf import settings
 from django.db import models
 from django.db.models import Max, Q
 from django.utils import timezone
@@ -26,7 +27,7 @@ class Signature(models.Model):
     @staticmethod
     def get_count() -> int:
         """Returns the number of verified signatures."""
-        return Signature.get_validated().count()
+        return settings.SIGNATURE_COUNTER_OFFSET + Signature.get_validated().count()
 
     @staticmethod
     def mark_email_as_verified(email: str, date: datetime):
@@ -59,7 +60,7 @@ class CallOutEmail(models.Model):
     content = models.TextField(null=False)
     subject = models.CharField(max_length=200)
     send_to_government = models.BooleanField()
-    circonscription_numbers = models.CharField(max_length=20, null=True, blank=True)
+    circonscription_numbers = models.CharField(max_length=35, null=True, blank=True)
     sender = models.CharField(max_length=100)
     from_email = models.CharField(max_length=60)
     postal_code = models.CharField(max_length=10)
@@ -98,6 +99,7 @@ class EmailOffset(models.Model):
 
 class BlackListedEmail(models.Model):
     """Just a list of forbidden emails."""
+
     created_at = models.DateTimeField(default=timezone.now)
     email = models.EmailField(db_index=True, unique=True)
 
